# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['CommonLicenseManageBigIqArgs', 'CommonLicenseManageBigIq']

@pulumi.input_type
class CommonLicenseManageBigIqArgs:
    def __init__(__self__, *,
                 assignment_type: pulumi.Input[str],
                 bigiq_address: pulumi.Input[str],
                 bigiq_password: pulumi.Input[str],
                 bigiq_user: pulumi.Input[str],
                 license_poolname: pulumi.Input[str],
                 bigiq_login_ref: Optional[pulumi.Input[str]] = None,
                 bigiq_port: Optional[pulumi.Input[str]] = None,
                 bigiq_token_auth: Optional[pulumi.Input[bool]] = None,
                 device_license_status: Optional[pulumi.Input[str]] = None,
                 hypervisor: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 mac_address: Optional[pulumi.Input[str]] = None,
                 skukeyword1: Optional[pulumi.Input[str]] = None,
                 skukeyword2: Optional[pulumi.Input[str]] = None,
                 tenant: Optional[pulumi.Input[str]] = None,
                 unit_of_measure: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a CommonLicenseManageBigIq resource.
        :param pulumi.Input[str] assignment_type: The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        :param pulumi.Input[str] bigiq_address: BIGIQ License Manager IP Address, variable type `string`
        :param pulumi.Input[str] bigiq_password: BIGIQ License Manager password.  variable type `string`
        :param pulumi.Input[str] bigiq_user: BIGIQ License Manager username, variable type `string`
        :param pulumi.Input[str] license_poolname: A name given to the license pool. type `string`
        :param pulumi.Input[str] bigiq_login_ref: BIGIQ Login reference for token authentication
        :param pulumi.Input[str] bigiq_port: type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        :param pulumi.Input[bool] bigiq_token_auth: type `bool`, if set to `true` enables Token based Authentication,default is `false`
        :param pulumi.Input[str] device_license_status: Status of Licence Assignment
        :param pulumi.Input[str] hypervisor: Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        :param pulumi.Input[str] key: License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        :param pulumi.Input[str] mac_address: MAC address of the BIG-IP. type `string`
        :param pulumi.Input[str] skukeyword1: An optional offering name. type `string`
        :param pulumi.Input[str] skukeyword2: An optional offering name. type `string`
        :param pulumi.Input[str] tenant: For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        :param pulumi.Input[str] unit_of_measure: The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        pulumi.set(__self__, "assignment_type", assignment_type)
        pulumi.set(__self__, "bigiq_address", bigiq_address)
        pulumi.set(__self__, "bigiq_password", bigiq_password)
        pulumi.set(__self__, "bigiq_user", bigiq_user)
        pulumi.set(__self__, "license_poolname", license_poolname)
        if bigiq_login_ref is not None:
            pulumi.set(__self__, "bigiq_login_ref", bigiq_login_ref)
        if bigiq_port is not None:
            pulumi.set(__self__, "bigiq_port", bigiq_port)
        if bigiq_token_auth is not None:
            pulumi.set(__self__, "bigiq_token_auth", bigiq_token_auth)
        if device_license_status is not None:
            pulumi.set(__self__, "device_license_status", device_license_status)
        if hypervisor is not None:
            pulumi.set(__self__, "hypervisor", hypervisor)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if skukeyword1 is not None:
            pulumi.set(__self__, "skukeyword1", skukeyword1)
        if skukeyword2 is not None:
            pulumi.set(__self__, "skukeyword2", skukeyword2)
        if tenant is not None:
            pulumi.set(__self__, "tenant", tenant)
        if unit_of_measure is not None:
            pulumi.set(__self__, "unit_of_measure", unit_of_measure)

    @property
    @pulumi.getter(name="assignmentType")
    def assignment_type(self) -> pulumi.Input[str]:
        """
        The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        """
        return pulumi.get(self, "assignment_type")

    @assignment_type.setter
    def assignment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "assignment_type", value)

    @property
    @pulumi.getter(name="bigiqAddress")
    def bigiq_address(self) -> pulumi.Input[str]:
        """
        BIGIQ License Manager IP Address, variable type `string`
        """
        return pulumi.get(self, "bigiq_address")

    @bigiq_address.setter
    def bigiq_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "bigiq_address", value)

    @property
    @pulumi.getter(name="bigiqPassword")
    def bigiq_password(self) -> pulumi.Input[str]:
        """
        BIGIQ License Manager password.  variable type `string`
        """
        return pulumi.get(self, "bigiq_password")

    @bigiq_password.setter
    def bigiq_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "bigiq_password", value)

    @property
    @pulumi.getter(name="bigiqUser")
    def bigiq_user(self) -> pulumi.Input[str]:
        """
        BIGIQ License Manager username, variable type `string`
        """
        return pulumi.get(self, "bigiq_user")

    @bigiq_user.setter
    def bigiq_user(self, value: pulumi.Input[str]):
        pulumi.set(self, "bigiq_user", value)

    @property
    @pulumi.getter(name="licensePoolname")
    def license_poolname(self) -> pulumi.Input[str]:
        """
        A name given to the license pool. type `string`
        """
        return pulumi.get(self, "license_poolname")

    @license_poolname.setter
    def license_poolname(self, value: pulumi.Input[str]):
        pulumi.set(self, "license_poolname", value)

    @property
    @pulumi.getter(name="bigiqLoginRef")
    def bigiq_login_ref(self) -> Optional[pulumi.Input[str]]:
        """
        BIGIQ Login reference for token authentication
        """
        return pulumi.get(self, "bigiq_login_ref")

    @bigiq_login_ref.setter
    def bigiq_login_ref(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_login_ref", value)

    @property
    @pulumi.getter(name="bigiqPort")
    def bigiq_port(self) -> Optional[pulumi.Input[str]]:
        """
        type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        """
        return pulumi.get(self, "bigiq_port")

    @bigiq_port.setter
    def bigiq_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_port", value)

    @property
    @pulumi.getter(name="bigiqTokenAuth")
    def bigiq_token_auth(self) -> Optional[pulumi.Input[bool]]:
        """
        type `bool`, if set to `true` enables Token based Authentication,default is `false`
        """
        return pulumi.get(self, "bigiq_token_auth")

    @bigiq_token_auth.setter
    def bigiq_token_auth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "bigiq_token_auth", value)

    @property
    @pulumi.getter(name="deviceLicenseStatus")
    def device_license_status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of Licence Assignment
        """
        return pulumi.get(self, "device_license_status")

    @device_license_status.setter
    def device_license_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "device_license_status", value)

    @property
    @pulumi.getter
    def hypervisor(self) -> Optional[pulumi.Input[str]]:
        """
        Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        """
        return pulumi.get(self, "hypervisor")

    @hypervisor.setter
    def hypervisor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hypervisor", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[str]]:
        """
        MAC address of the BIG-IP. type `string`
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_address", value)

    @property
    @pulumi.getter
    def skukeyword1(self) -> Optional[pulumi.Input[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword1")

    @skukeyword1.setter
    def skukeyword1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "skukeyword1", value)

    @property
    @pulumi.getter
    def skukeyword2(self) -> Optional[pulumi.Input[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword2")

    @skukeyword2.setter
    def skukeyword2(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "skukeyword2", value)

    @property
    @pulumi.getter
    def tenant(self) -> Optional[pulumi.Input[str]]:
        """
        For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        """
        return pulumi.get(self, "tenant")

    @tenant.setter
    def tenant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant", value)

    @property
    @pulumi.getter(name="unitOfMeasure")
    def unit_of_measure(self) -> Optional[pulumi.Input[str]]:
        """
        The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        return pulumi.get(self, "unit_of_measure")

    @unit_of_measure.setter
    def unit_of_measure(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "unit_of_measure", value)


@pulumi.input_type
class _CommonLicenseManageBigIqState:
    def __init__(__self__, *,
                 assignment_type: Optional[pulumi.Input[str]] = None,
                 bigiq_address: Optional[pulumi.Input[str]] = None,
                 bigiq_login_ref: Optional[pulumi.Input[str]] = None,
                 bigiq_password: Optional[pulumi.Input[str]] = None,
                 bigiq_port: Optional[pulumi.Input[str]] = None,
                 bigiq_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigiq_user: Optional[pulumi.Input[str]] = None,
                 device_license_status: Optional[pulumi.Input[str]] = None,
                 hypervisor: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 license_poolname: Optional[pulumi.Input[str]] = None,
                 mac_address: Optional[pulumi.Input[str]] = None,
                 skukeyword1: Optional[pulumi.Input[str]] = None,
                 skukeyword2: Optional[pulumi.Input[str]] = None,
                 tenant: Optional[pulumi.Input[str]] = None,
                 unit_of_measure: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CommonLicenseManageBigIq resources.
        :param pulumi.Input[str] assignment_type: The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        :param pulumi.Input[str] bigiq_address: BIGIQ License Manager IP Address, variable type `string`
        :param pulumi.Input[str] bigiq_login_ref: BIGIQ Login reference for token authentication
        :param pulumi.Input[str] bigiq_password: BIGIQ License Manager password.  variable type `string`
        :param pulumi.Input[str] bigiq_port: type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        :param pulumi.Input[bool] bigiq_token_auth: type `bool`, if set to `true` enables Token based Authentication,default is `false`
        :param pulumi.Input[str] bigiq_user: BIGIQ License Manager username, variable type `string`
        :param pulumi.Input[str] device_license_status: Status of Licence Assignment
        :param pulumi.Input[str] hypervisor: Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        :param pulumi.Input[str] key: License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        :param pulumi.Input[str] license_poolname: A name given to the license pool. type `string`
        :param pulumi.Input[str] mac_address: MAC address of the BIG-IP. type `string`
        :param pulumi.Input[str] skukeyword1: An optional offering name. type `string`
        :param pulumi.Input[str] skukeyword2: An optional offering name. type `string`
        :param pulumi.Input[str] tenant: For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        :param pulumi.Input[str] unit_of_measure: The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        if assignment_type is not None:
            pulumi.set(__self__, "assignment_type", assignment_type)
        if bigiq_address is not None:
            pulumi.set(__self__, "bigiq_address", bigiq_address)
        if bigiq_login_ref is not None:
            pulumi.set(__self__, "bigiq_login_ref", bigiq_login_ref)
        if bigiq_password is not None:
            pulumi.set(__self__, "bigiq_password", bigiq_password)
        if bigiq_port is not None:
            pulumi.set(__self__, "bigiq_port", bigiq_port)
        if bigiq_token_auth is not None:
            pulumi.set(__self__, "bigiq_token_auth", bigiq_token_auth)
        if bigiq_user is not None:
            pulumi.set(__self__, "bigiq_user", bigiq_user)
        if device_license_status is not None:
            pulumi.set(__self__, "device_license_status", device_license_status)
        if hypervisor is not None:
            pulumi.set(__self__, "hypervisor", hypervisor)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if license_poolname is not None:
            pulumi.set(__self__, "license_poolname", license_poolname)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if skukeyword1 is not None:
            pulumi.set(__self__, "skukeyword1", skukeyword1)
        if skukeyword2 is not None:
            pulumi.set(__self__, "skukeyword2", skukeyword2)
        if tenant is not None:
            pulumi.set(__self__, "tenant", tenant)
        if unit_of_measure is not None:
            pulumi.set(__self__, "unit_of_measure", unit_of_measure)

    @property
    @pulumi.getter(name="assignmentType")
    def assignment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        """
        return pulumi.get(self, "assignment_type")

    @assignment_type.setter
    def assignment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assignment_type", value)

    @property
    @pulumi.getter(name="bigiqAddress")
    def bigiq_address(self) -> Optional[pulumi.Input[str]]:
        """
        BIGIQ License Manager IP Address, variable type `string`
        """
        return pulumi.get(self, "bigiq_address")

    @bigiq_address.setter
    def bigiq_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_address", value)

    @property
    @pulumi.getter(name="bigiqLoginRef")
    def bigiq_login_ref(self) -> Optional[pulumi.Input[str]]:
        """
        BIGIQ Login reference for token authentication
        """
        return pulumi.get(self, "bigiq_login_ref")

    @bigiq_login_ref.setter
    def bigiq_login_ref(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_login_ref", value)

    @property
    @pulumi.getter(name="bigiqPassword")
    def bigiq_password(self) -> Optional[pulumi.Input[str]]:
        """
        BIGIQ License Manager password.  variable type `string`
        """
        return pulumi.get(self, "bigiq_password")

    @bigiq_password.setter
    def bigiq_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_password", value)

    @property
    @pulumi.getter(name="bigiqPort")
    def bigiq_port(self) -> Optional[pulumi.Input[str]]:
        """
        type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        """
        return pulumi.get(self, "bigiq_port")

    @bigiq_port.setter
    def bigiq_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_port", value)

    @property
    @pulumi.getter(name="bigiqTokenAuth")
    def bigiq_token_auth(self) -> Optional[pulumi.Input[bool]]:
        """
        type `bool`, if set to `true` enables Token based Authentication,default is `false`
        """
        return pulumi.get(self, "bigiq_token_auth")

    @bigiq_token_auth.setter
    def bigiq_token_auth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "bigiq_token_auth", value)

    @property
    @pulumi.getter(name="bigiqUser")
    def bigiq_user(self) -> Optional[pulumi.Input[str]]:
        """
        BIGIQ License Manager username, variable type `string`
        """
        return pulumi.get(self, "bigiq_user")

    @bigiq_user.setter
    def bigiq_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bigiq_user", value)

    @property
    @pulumi.getter(name="deviceLicenseStatus")
    def device_license_status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of Licence Assignment
        """
        return pulumi.get(self, "device_license_status")

    @device_license_status.setter
    def device_license_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "device_license_status", value)

    @property
    @pulumi.getter
    def hypervisor(self) -> Optional[pulumi.Input[str]]:
        """
        Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        """
        return pulumi.get(self, "hypervisor")

    @hypervisor.setter
    def hypervisor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hypervisor", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="licensePoolname")
    def license_poolname(self) -> Optional[pulumi.Input[str]]:
        """
        A name given to the license pool. type `string`
        """
        return pulumi.get(self, "license_poolname")

    @license_poolname.setter
    def license_poolname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "license_poolname", value)

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[str]]:
        """
        MAC address of the BIG-IP. type `string`
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_address", value)

    @property
    @pulumi.getter
    def skukeyword1(self) -> Optional[pulumi.Input[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword1")

    @skukeyword1.setter
    def skukeyword1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "skukeyword1", value)

    @property
    @pulumi.getter
    def skukeyword2(self) -> Optional[pulumi.Input[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword2")

    @skukeyword2.setter
    def skukeyword2(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "skukeyword2", value)

    @property
    @pulumi.getter
    def tenant(self) -> Optional[pulumi.Input[str]]:
        """
        For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        """
        return pulumi.get(self, "tenant")

    @tenant.setter
    def tenant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant", value)

    @property
    @pulumi.getter(name="unitOfMeasure")
    def unit_of_measure(self) -> Optional[pulumi.Input[str]]:
        """
        The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        return pulumi.get(self, "unit_of_measure")

    @unit_of_measure.setter
    def unit_of_measure(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "unit_of_measure", value)


class CommonLicenseManageBigIq(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignment_type: Optional[pulumi.Input[str]] = None,
                 bigiq_address: Optional[pulumi.Input[str]] = None,
                 bigiq_login_ref: Optional[pulumi.Input[str]] = None,
                 bigiq_password: Optional[pulumi.Input[str]] = None,
                 bigiq_port: Optional[pulumi.Input[str]] = None,
                 bigiq_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigiq_user: Optional[pulumi.Input[str]] = None,
                 device_license_status: Optional[pulumi.Input[str]] = None,
                 hypervisor: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 license_poolname: Optional[pulumi.Input[str]] = None,
                 mac_address: Optional[pulumi.Input[str]] = None,
                 skukeyword1: Optional[pulumi.Input[str]] = None,
                 skukeyword2: Optional[pulumi.Input[str]] = None,
                 tenant: Optional[pulumi.Input[str]] = None,
                 unit_of_measure: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `CommonLicenseManageBigIq` This Resource is used for BIGIP/Provider License Management from BIGIQ

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        # MANAGED Regkey Pool
        test_example_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="regkeypool_name",
            assignment_type="MANAGED")
        # UNMANAGED Regkey Pool
        test_example_index_common_license_manage_big_iq_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleIndex/commonLicenseManageBigIqCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="regkeypool_name",
            assignment_type="UNMANAGED")
        # UNMANAGED Utility Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="utilitypool_name",
            assignment_type="UNMANAGED",
            unit_of_measure="yearly",
            skukeyword1="BTHSM200M")
        # UNREACHABLE Regkey Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq1 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq1",
            bigiq_address="xxx.xxx.xxx.xxx",
            bigiq_user="xxxx",
            bigiq_password="xxxxx",
            license_poolname="regkey_pool_name",
            assignment_type="UNREACHABLE",
            mac_address="FA:16:3E:1B:6D:32",
            hypervisor="azure")
        # MANAGED Purchased Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq2 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq2",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="purchased_pool_name",
            assignment_type="MANAGED")
        # UNMANAGED Purchased Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq3 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq3",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="purchased_pool_name",
            assignment_type="UNMANAGED")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] assignment_type: The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        :param pulumi.Input[str] bigiq_address: BIGIQ License Manager IP Address, variable type `string`
        :param pulumi.Input[str] bigiq_login_ref: BIGIQ Login reference for token authentication
        :param pulumi.Input[str] bigiq_password: BIGIQ License Manager password.  variable type `string`
        :param pulumi.Input[str] bigiq_port: type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        :param pulumi.Input[bool] bigiq_token_auth: type `bool`, if set to `true` enables Token based Authentication,default is `false`
        :param pulumi.Input[str] bigiq_user: BIGIQ License Manager username, variable type `string`
        :param pulumi.Input[str] device_license_status: Status of Licence Assignment
        :param pulumi.Input[str] hypervisor: Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        :param pulumi.Input[str] key: License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        :param pulumi.Input[str] license_poolname: A name given to the license pool. type `string`
        :param pulumi.Input[str] mac_address: MAC address of the BIG-IP. type `string`
        :param pulumi.Input[str] skukeyword1: An optional offering name. type `string`
        :param pulumi.Input[str] skukeyword2: An optional offering name. type `string`
        :param pulumi.Input[str] tenant: For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        :param pulumi.Input[str] unit_of_measure: The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CommonLicenseManageBigIqArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `CommonLicenseManageBigIq` This Resource is used for BIGIP/Provider License Management from BIGIQ

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        # MANAGED Regkey Pool
        test_example_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="regkeypool_name",
            assignment_type="MANAGED")
        # UNMANAGED Regkey Pool
        test_example_index_common_license_manage_big_iq_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleIndex/commonLicenseManageBigIqCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="regkeypool_name",
            assignment_type="UNMANAGED")
        # UNMANAGED Utility Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="utilitypool_name",
            assignment_type="UNMANAGED",
            unit_of_measure="yearly",
            skukeyword1="BTHSM200M")
        # UNREACHABLE Regkey Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq1 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq1",
            bigiq_address="xxx.xxx.xxx.xxx",
            bigiq_user="xxxx",
            bigiq_password="xxxxx",
            license_poolname="regkey_pool_name",
            assignment_type="UNREACHABLE",
            mac_address="FA:16:3E:1B:6D:32",
            hypervisor="azure")
        # MANAGED Purchased Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq2 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq2",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="purchased_pool_name",
            assignment_type="MANAGED")
        # UNMANAGED Purchased Pool
        test_example_f5bigip_index_common_license_manage_big_iq_common_license_manage_big_iq3 = f5bigip.CommonLicenseManageBigIq("testExampleF5bigipIndex/commonLicenseManageBigIqCommonLicenseManageBigIq3",
            bigiq_address=var["bigiq"],
            bigiq_user=var["bigiq_un"],
            bigiq_password=var["bigiq_pw"],
            license_poolname="purchased_pool_name",
            assignment_type="UNMANAGED")
        ```

        :param str resource_name: The name of the resource.
        :param CommonLicenseManageBigIqArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CommonLicenseManageBigIqArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignment_type: Optional[pulumi.Input[str]] = None,
                 bigiq_address: Optional[pulumi.Input[str]] = None,
                 bigiq_login_ref: Optional[pulumi.Input[str]] = None,
                 bigiq_password: Optional[pulumi.Input[str]] = None,
                 bigiq_port: Optional[pulumi.Input[str]] = None,
                 bigiq_token_auth: Optional[pulumi.Input[bool]] = None,
                 bigiq_user: Optional[pulumi.Input[str]] = None,
                 device_license_status: Optional[pulumi.Input[str]] = None,
                 hypervisor: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 license_poolname: Optional[pulumi.Input[str]] = None,
                 mac_address: Optional[pulumi.Input[str]] = None,
                 skukeyword1: Optional[pulumi.Input[str]] = None,
                 skukeyword2: Optional[pulumi.Input[str]] = None,
                 tenant: Optional[pulumi.Input[str]] = None,
                 unit_of_measure: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CommonLicenseManageBigIqArgs.__new__(CommonLicenseManageBigIqArgs)

            if assignment_type is None and not opts.urn:
                raise TypeError("Missing required property 'assignment_type'")
            __props__.__dict__["assignment_type"] = assignment_type
            if bigiq_address is None and not opts.urn:
                raise TypeError("Missing required property 'bigiq_address'")
            __props__.__dict__["bigiq_address"] = bigiq_address
            __props__.__dict__["bigiq_login_ref"] = None if bigiq_login_ref is None else pulumi.Output.secret(bigiq_login_ref)
            if bigiq_password is None and not opts.urn:
                raise TypeError("Missing required property 'bigiq_password'")
            __props__.__dict__["bigiq_password"] = None if bigiq_password is None else pulumi.Output.secret(bigiq_password)
            __props__.__dict__["bigiq_port"] = None if bigiq_port is None else pulumi.Output.secret(bigiq_port)
            __props__.__dict__["bigiq_token_auth"] = None if bigiq_token_auth is None else pulumi.Output.secret(bigiq_token_auth)
            if bigiq_user is None and not opts.urn:
                raise TypeError("Missing required property 'bigiq_user'")
            __props__.__dict__["bigiq_user"] = None if bigiq_user is None else pulumi.Output.secret(bigiq_user)
            __props__.__dict__["device_license_status"] = device_license_status
            __props__.__dict__["hypervisor"] = hypervisor
            __props__.__dict__["key"] = key
            if license_poolname is None and not opts.urn:
                raise TypeError("Missing required property 'license_poolname'")
            __props__.__dict__["license_poolname"] = license_poolname
            __props__.__dict__["mac_address"] = mac_address
            __props__.__dict__["skukeyword1"] = skukeyword1
            __props__.__dict__["skukeyword2"] = skukeyword2
            __props__.__dict__["tenant"] = tenant
            __props__.__dict__["unit_of_measure"] = unit_of_measure
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["bigiqLoginRef", "bigiqPassword", "bigiqPort", "bigiqTokenAuth", "bigiqUser"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(CommonLicenseManageBigIq, __self__).__init__(
            'f5bigip:index/commonLicenseManageBigIq:CommonLicenseManageBigIq',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            assignment_type: Optional[pulumi.Input[str]] = None,
            bigiq_address: Optional[pulumi.Input[str]] = None,
            bigiq_login_ref: Optional[pulumi.Input[str]] = None,
            bigiq_password: Optional[pulumi.Input[str]] = None,
            bigiq_port: Optional[pulumi.Input[str]] = None,
            bigiq_token_auth: Optional[pulumi.Input[bool]] = None,
            bigiq_user: Optional[pulumi.Input[str]] = None,
            device_license_status: Optional[pulumi.Input[str]] = None,
            hypervisor: Optional[pulumi.Input[str]] = None,
            key: Optional[pulumi.Input[str]] = None,
            license_poolname: Optional[pulumi.Input[str]] = None,
            mac_address: Optional[pulumi.Input[str]] = None,
            skukeyword1: Optional[pulumi.Input[str]] = None,
            skukeyword2: Optional[pulumi.Input[str]] = None,
            tenant: Optional[pulumi.Input[str]] = None,
            unit_of_measure: Optional[pulumi.Input[str]] = None) -> 'CommonLicenseManageBigIq':
        """
        Get an existing CommonLicenseManageBigIq resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] assignment_type: The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        :param pulumi.Input[str] bigiq_address: BIGIQ License Manager IP Address, variable type `string`
        :param pulumi.Input[str] bigiq_login_ref: BIGIQ Login reference for token authentication
        :param pulumi.Input[str] bigiq_password: BIGIQ License Manager password.  variable type `string`
        :param pulumi.Input[str] bigiq_port: type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        :param pulumi.Input[bool] bigiq_token_auth: type `bool`, if set to `true` enables Token based Authentication,default is `false`
        :param pulumi.Input[str] bigiq_user: BIGIQ License Manager username, variable type `string`
        :param pulumi.Input[str] device_license_status: Status of Licence Assignment
        :param pulumi.Input[str] hypervisor: Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        :param pulumi.Input[str] key: License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        :param pulumi.Input[str] license_poolname: A name given to the license pool. type `string`
        :param pulumi.Input[str] mac_address: MAC address of the BIG-IP. type `string`
        :param pulumi.Input[str] skukeyword1: An optional offering name. type `string`
        :param pulumi.Input[str] skukeyword2: An optional offering name. type `string`
        :param pulumi.Input[str] tenant: For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        :param pulumi.Input[str] unit_of_measure: The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CommonLicenseManageBigIqState.__new__(_CommonLicenseManageBigIqState)

        __props__.__dict__["assignment_type"] = assignment_type
        __props__.__dict__["bigiq_address"] = bigiq_address
        __props__.__dict__["bigiq_login_ref"] = bigiq_login_ref
        __props__.__dict__["bigiq_password"] = bigiq_password
        __props__.__dict__["bigiq_port"] = bigiq_port
        __props__.__dict__["bigiq_token_auth"] = bigiq_token_auth
        __props__.__dict__["bigiq_user"] = bigiq_user
        __props__.__dict__["device_license_status"] = device_license_status
        __props__.__dict__["hypervisor"] = hypervisor
        __props__.__dict__["key"] = key
        __props__.__dict__["license_poolname"] = license_poolname
        __props__.__dict__["mac_address"] = mac_address
        __props__.__dict__["skukeyword1"] = skukeyword1
        __props__.__dict__["skukeyword2"] = skukeyword2
        __props__.__dict__["tenant"] = tenant
        __props__.__dict__["unit_of_measure"] = unit_of_measure
        return CommonLicenseManageBigIq(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="assignmentType")
    def assignment_type(self) -> pulumi.Output[str]:
        """
        The type of assignment, which is determined by whether the BIG-IP is unreachable, unmanaged, or managed by BIG-IQ. Possible values: “UNREACHABLE”, “UNMANAGED”, or “MANAGED”.
        """
        return pulumi.get(self, "assignment_type")

    @property
    @pulumi.getter(name="bigiqAddress")
    def bigiq_address(self) -> pulumi.Output[str]:
        """
        BIGIQ License Manager IP Address, variable type `string`
        """
        return pulumi.get(self, "bigiq_address")

    @property
    @pulumi.getter(name="bigiqLoginRef")
    def bigiq_login_ref(self) -> pulumi.Output[Optional[str]]:
        """
        BIGIQ Login reference for token authentication
        """
        return pulumi.get(self, "bigiq_login_ref")

    @property
    @pulumi.getter(name="bigiqPassword")
    def bigiq_password(self) -> pulumi.Output[str]:
        """
        BIGIQ License Manager password.  variable type `string`
        """
        return pulumi.get(self, "bigiq_password")

    @property
    @pulumi.getter(name="bigiqPort")
    def bigiq_port(self) -> pulumi.Output[Optional[str]]:
        """
        type `int`, BIGIQ License Manager Port number, specify if port is other than `443`
        """
        return pulumi.get(self, "bigiq_port")

    @property
    @pulumi.getter(name="bigiqTokenAuth")
    def bigiq_token_auth(self) -> pulumi.Output[Optional[bool]]:
        """
        type `bool`, if set to `true` enables Token based Authentication,default is `false`
        """
        return pulumi.get(self, "bigiq_token_auth")

    @property
    @pulumi.getter(name="bigiqUser")
    def bigiq_user(self) -> pulumi.Output[str]:
        """
        BIGIQ License Manager username, variable type `string`
        """
        return pulumi.get(self, "bigiq_user")

    @property
    @pulumi.getter(name="deviceLicenseStatus")
    def device_license_status(self) -> pulumi.Output[str]:
        """
        Status of Licence Assignment
        """
        return pulumi.get(self, "device_license_status")

    @property
    @pulumi.getter
    def hypervisor(self) -> pulumi.Output[Optional[str]]:
        """
        Identifies the platform running the BIG-IP VE. Possible values: “aws”, “azure”, “gce”, “vmware”, “hyperv”, “kvm”, or “xen”. type `string`
        """
        return pulumi.get(self, "hypervisor")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[Optional[str]]:
        """
        License Assignment is done with specified `key`, supported only with RegKeypool type License assignement. type `string`
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="licensePoolname")
    def license_poolname(self) -> pulumi.Output[str]:
        """
        A name given to the license pool. type `string`
        """
        return pulumi.get(self, "license_poolname")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> pulumi.Output[Optional[str]]:
        """
        MAC address of the BIG-IP. type `string`
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter
    def skukeyword1(self) -> pulumi.Output[Optional[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword1")

    @property
    @pulumi.getter
    def skukeyword2(self) -> pulumi.Output[Optional[str]]:
        """
        An optional offering name. type `string`
        """
        return pulumi.get(self, "skukeyword2")

    @property
    @pulumi.getter
    def tenant(self) -> pulumi.Output[Optional[str]]:
        """
        For an unreachable BIG-IP, you can provide an optional description for the assignment in this field.
        """
        return pulumi.get(self, "tenant")

    @property
    @pulumi.getter(name="unitOfMeasure")
    def unit_of_measure(self) -> pulumi.Output[Optional[str]]:
        """
        The units used to measure billing. For example, “hourly” or “daily”. Type `string`
        """
        return pulumi.get(self, "unit_of_measure")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'IAppListArgs',
    'IAppMetadataArgs',
    'IAppTableArgs',
    'IAppTableRowArgs',
    'IAppVariableArgs',
]

@pulumi.input_type
class IAppListArgs:
    def __init__(__self__, *,
                 encrypted: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class IAppMetadataArgs:
    def __init__(__self__, *,
                 persists: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        if persists is not None:
            pulumi.set(__self__, "persists", persists)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def persists(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "persists")

    @persists.setter
    def persists(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "persists", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class IAppTableArgs:
    def __init__(__self__, *,
                 column_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 encrypted_columns: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 rows: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]] = None):
        """
        :param pulumi.Input[str] name: Name of the iApp.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if encrypted_columns is not None:
            pulumi.set(__self__, "encrypted_columns", encrypted_columns)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "column_names")

    @column_names.setter
    def column_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "column_names", value)

    @property
    @pulumi.getter(name="encryptedColumns")
    def encrypted_columns(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encrypted_columns")

    @encrypted_columns.setter
    def encrypted_columns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypted_columns", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def rows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]]:
        return pulumi.get(self, "rows")

    @rows.setter
    def rows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]]):
        pulumi.set(self, "rows", value)


@pulumi.input_type
class IAppTableRowArgs:
    def __init__(__self__, *,
                 rows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @property
    @pulumi.getter
    def rows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "rows")

    @rows.setter
    def rows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "rows", value)


@pulumi.input_type
class IAppVariableArgs:
    def __init__(__self__, *,
                 encrypted: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] name: Name of the iApp.
        """
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ProvisionArgs', 'Provision']

@pulumi.input_type
class ProvisionArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 cpu_ratio: Optional[pulumi.Input[int]] = None,
                 disk_ratio: Optional[pulumi.Input[int]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 memory_ratio: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Provision resource.
        :param pulumi.Input[str] name: Name of module to provision in BIG-IP. 
               possible options:
               * afm
               * am
               * apm
               * cgnat
               * asm
               * avr
               * dos
               * fps
               * gtm
               * ilx
               * lc
               * ltm
               * pem
               * sslo
               * swg
               * urldb
        :param pulumi.Input[int] cpu_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[int] disk_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] level: Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
               default is `nominal`
               possible options:
               * nominal
               * minimum
               * none
               * dedicated
        :param pulumi.Input[int] memory_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        pulumi.set(__self__, "name", name)
        if cpu_ratio is not None:
            pulumi.set(__self__, "cpu_ratio", cpu_ratio)
        if disk_ratio is not None:
            pulumi.set(__self__, "disk_ratio", disk_ratio)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if memory_ratio is not None:
            pulumi.set(__self__, "memory_ratio", memory_ratio)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of module to provision in BIG-IP. 
        possible options:
        * afm
        * am
        * apm
        * cgnat
        * asm
        * avr
        * dos
        * fps
        * gtm
        * ilx
        * lc
        * ltm
        * pem
        * sslo
        * swg
        * urldb
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="cpuRatio")
    def cpu_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "cpu_ratio")

    @cpu_ratio.setter
    def cpu_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu_ratio", value)

    @property
    @pulumi.getter(name="diskRatio")
    def disk_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "disk_ratio")

    @disk_ratio.setter
    def disk_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_ratio", value)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_path", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[str]]:
        """
        Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
        default is `nominal`
        possible options:
        * nominal
        * minimum
        * none
        * dedicated
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="memoryRatio")
    def memory_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "memory_ratio")

    @memory_ratio.setter
    def memory_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_ratio", value)


@pulumi.input_type
class _ProvisionState:
    def __init__(__self__, *,
                 cpu_ratio: Optional[pulumi.Input[int]] = None,
                 disk_ratio: Optional[pulumi.Input[int]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 memory_ratio: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Provision resources.
        :param pulumi.Input[int] cpu_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[int] disk_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] level: Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
               default is `nominal`
               possible options:
               * nominal
               * minimum
               * none
               * dedicated
        :param pulumi.Input[int] memory_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] name: Name of module to provision in BIG-IP. 
               possible options:
               * afm
               * am
               * apm
               * cgnat
               * asm
               * avr
               * dos
               * fps
               * gtm
               * ilx
               * lc
               * ltm
               * pem
               * sslo
               * swg
               * urldb
        """
        if cpu_ratio is not None:
            pulumi.set(__self__, "cpu_ratio", cpu_ratio)
        if disk_ratio is not None:
            pulumi.set(__self__, "disk_ratio", disk_ratio)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if memory_ratio is not None:
            pulumi.set(__self__, "memory_ratio", memory_ratio)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="cpuRatio")
    def cpu_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "cpu_ratio")

    @cpu_ratio.setter
    def cpu_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu_ratio", value)

    @property
    @pulumi.getter(name="diskRatio")
    def disk_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "disk_ratio")

    @disk_ratio.setter
    def disk_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_ratio", value)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_path", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[str]]:
        """
        Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
        default is `nominal`
        possible options:
        * nominal
        * minimum
        * none
        * dedicated
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="memoryRatio")
    def memory_ratio(self) -> Optional[pulumi.Input[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "memory_ratio")

    @memory_ratio.setter
    def memory_ratio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_ratio", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of module to provision in BIG-IP. 
        possible options:
        * afm
        * am
        * apm
        * cgnat
        * asm
        * avr
        * dos
        * fps
        * gtm
        * ilx
        * lc
        * ltm
        * pem
        * sslo
        * swg
        * urldb
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Provision(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cpu_ratio: Optional[pulumi.Input[int]] = None,
                 disk_ratio: Optional[pulumi.Input[int]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 memory_ratio: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `sys.Provision` Manage BIG-IP module provisioning. This resource will only provision at the standard levels of Dedicated, Nominal, and Minimum.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        gtm = f5bigip.sys.Provision("gtm",
            cpu_ratio=0,
            disk_ratio=0,
            level="nominal",
            memory_ratio=0,
            name="gtm")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cpu_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[int] disk_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] level: Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
               default is `nominal`
               possible options:
               * nominal
               * minimum
               * none
               * dedicated
        :param pulumi.Input[int] memory_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] name: Name of module to provision in BIG-IP. 
               possible options:
               * afm
               * am
               * apm
               * cgnat
               * asm
               * avr
               * dos
               * fps
               * gtm
               * ilx
               * lc
               * ltm
               * pem
               * sslo
               * swg
               * urldb
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProvisionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.Provision` Manage BIG-IP module provisioning. This resource will only provision at the standard levels of Dedicated, Nominal, and Minimum.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        gtm = f5bigip.sys.Provision("gtm",
            cpu_ratio=0,
            disk_ratio=0,
            level="nominal",
            memory_ratio=0,
            name="gtm")
        ```

        :param str resource_name: The name of the resource.
        :param ProvisionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProvisionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cpu_ratio: Optional[pulumi.Input[int]] = None,
                 disk_ratio: Optional[pulumi.Input[int]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 memory_ratio: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProvisionArgs.__new__(ProvisionArgs)

            __props__.__dict__["cpu_ratio"] = cpu_ratio
            __props__.__dict__["disk_ratio"] = disk_ratio
            __props__.__dict__["full_path"] = full_path
            __props__.__dict__["level"] = level
            __props__.__dict__["memory_ratio"] = memory_ratio
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
        super(Provision, __self__).__init__(
            'f5bigip:sys/provision:Provision',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cpu_ratio: Optional[pulumi.Input[int]] = None,
            disk_ratio: Optional[pulumi.Input[int]] = None,
            full_path: Optional[pulumi.Input[str]] = None,
            level: Optional[pulumi.Input[str]] = None,
            memory_ratio: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Provision':
        """
        Get an existing Provision resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cpu_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[int] disk_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] level: Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
               default is `nominal`
               possible options:
               * nominal
               * minimum
               * none
               * dedicated
        :param pulumi.Input[int] memory_ratio: Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        :param pulumi.Input[str] name: Name of module to provision in BIG-IP. 
               possible options:
               * afm
               * am
               * apm
               * cgnat
               * asm
               * avr
               * dos
               * fps
               * gtm
               * ilx
               * lc
               * ltm
               * pem
               * sslo
               * swg
               * urldb
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProvisionState.__new__(_ProvisionState)

        __props__.__dict__["cpu_ratio"] = cpu_ratio
        __props__.__dict__["disk_ratio"] = disk_ratio
        __props__.__dict__["full_path"] = full_path
        __props__.__dict__["level"] = level
        __props__.__dict__["memory_ratio"] = memory_ratio
        __props__.__dict__["name"] = name
        return Provision(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cpuRatio")
    def cpu_ratio(self) -> pulumi.Output[Optional[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "cpu_ratio")

    @property
    @pulumi.getter(name="diskRatio")
    def disk_ratio(self) -> pulumi.Output[Optional[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "disk_ratio")

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> pulumi.Output[str]:
        return pulumi.get(self, "full_path")

    @property
    @pulumi.getter
    def level(self) -> pulumi.Output[Optional[str]]:
        """
        Sets the provisioning level for the requested modules. Changing the level for one module may require modifying the level of another module. For example, changing one module to `dedicated` requires setting all others to `none`. Setting the level of a module to `none` means the module is not activated.
        default is `nominal`
        possible options:
        * nominal
        * minimum
        * none
        * dedicated
        """
        return pulumi.get(self, "level")

    @property
    @pulumi.getter(name="memoryRatio")
    def memory_ratio(self) -> pulumi.Output[Optional[int]]:
        """
        Use this option only when the level option is set to custom.F5 Networks recommends that you do not modify this option. The default value is none
        """
        return pulumi.get(self, "memory_ratio")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of module to provision in BIG-IP. 
        possible options:
        * afm
        * am
        * apm
        * cgnat
        * asm
        * avr
        * dos
        * fps
        * gtm
        * ilx
        * lc
        * ltm
        * pem
        * sslo
        * swg
        * urldb
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetWafEntityParameterResult',
    'AwaitableGetWafEntityParameterResult',
    'get_waf_entity_parameter',
    'get_waf_entity_parameter_output',
]

@pulumi.output_type
class GetWafEntityParameterResult:
    """
    A collection of values returned by getWafEntityParameter.
    """
    def __init__(__self__, allow_empty_type=None, allow_repeated_parameter_name=None, attack_signatures_check=None, check_max_value_length=None, check_min_value_length=None, data_type=None, description=None, enable_regular_expression=None, id=None, is_base64=None, is_cookie=None, is_header=None, json=None, level=None, mandatory=None, metachars_on_parameter_value_check=None, name=None, parameter_location=None, perform_staging=None, sensitive_parameter=None, signature_overrides_disables=None, type=None, url=None, value_type=None):
        if allow_empty_type and not isinstance(allow_empty_type, bool):
            raise TypeError("Expected argument 'allow_empty_type' to be a bool")
        pulumi.set(__self__, "allow_empty_type", allow_empty_type)
        if allow_repeated_parameter_name and not isinstance(allow_repeated_parameter_name, bool):
            raise TypeError("Expected argument 'allow_repeated_parameter_name' to be a bool")
        pulumi.set(__self__, "allow_repeated_parameter_name", allow_repeated_parameter_name)
        if attack_signatures_check and not isinstance(attack_signatures_check, bool):
            raise TypeError("Expected argument 'attack_signatures_check' to be a bool")
        pulumi.set(__self__, "attack_signatures_check", attack_signatures_check)
        if check_max_value_length and not isinstance(check_max_value_length, bool):
            raise TypeError("Expected argument 'check_max_value_length' to be a bool")
        pulumi.set(__self__, "check_max_value_length", check_max_value_length)
        if check_min_value_length and not isinstance(check_min_value_length, bool):
            raise TypeError("Expected argument 'check_min_value_length' to be a bool")
        pulumi.set(__self__, "check_min_value_length", check_min_value_length)
        if data_type and not isinstance(data_type, str):
            raise TypeError("Expected argument 'data_type' to be a str")
        pulumi.set(__self__, "data_type", data_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_regular_expression and not isinstance(enable_regular_expression, bool):
            raise TypeError("Expected argument 'enable_regular_expression' to be a bool")
        pulumi.set(__self__, "enable_regular_expression", enable_regular_expression)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_base64 and not isinstance(is_base64, bool):
            raise TypeError("Expected argument 'is_base64' to be a bool")
        pulumi.set(__self__, "is_base64", is_base64)
        if is_cookie and not isinstance(is_cookie, bool):
            raise TypeError("Expected argument 'is_cookie' to be a bool")
        pulumi.set(__self__, "is_cookie", is_cookie)
        if is_header and not isinstance(is_header, bool):
            raise TypeError("Expected argument 'is_header' to be a bool")
        pulumi.set(__self__, "is_header", is_header)
        if json and not isinstance(json, str):
            raise TypeError("Expected argument 'json' to be a str")
        pulumi.set(__self__, "json", json)
        if level and not isinstance(level, str):
            raise TypeError("Expected argument 'level' to be a str")
        pulumi.set(__self__, "level", level)
        if mandatory and not isinstance(mandatory, bool):
            raise TypeError("Expected argument 'mandatory' to be a bool")
        pulumi.set(__self__, "mandatory", mandatory)
        if metachars_on_parameter_value_check and not isinstance(metachars_on_parameter_value_check, bool):
            raise TypeError("Expected argument 'metachars_on_parameter_value_check' to be a bool")
        pulumi.set(__self__, "metachars_on_parameter_value_check", metachars_on_parameter_value_check)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parameter_location and not isinstance(parameter_location, str):
            raise TypeError("Expected argument 'parameter_location' to be a str")
        pulumi.set(__self__, "parameter_location", parameter_location)
        if perform_staging and not isinstance(perform_staging, bool):
            raise TypeError("Expected argument 'perform_staging' to be a bool")
        pulumi.set(__self__, "perform_staging", perform_staging)
        if sensitive_parameter and not isinstance(sensitive_parameter, bool):
            raise TypeError("Expected argument 'sensitive_parameter' to be a bool")
        pulumi.set(__self__, "sensitive_parameter", sensitive_parameter)
        if signature_overrides_disables and not isinstance(signature_overrides_disables, list):
            raise TypeError("Expected argument 'signature_overrides_disables' to be a list")
        pulumi.set(__self__, "signature_overrides_disables", signature_overrides_disables)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if url and not isinstance(url, dict):
            raise TypeError("Expected argument 'url' to be a dict")
        pulumi.set(__self__, "url", url)
        if value_type and not isinstance(value_type, str):
            raise TypeError("Expected argument 'value_type' to be a str")
        pulumi.set(__self__, "value_type", value_type)

    @property
    @pulumi.getter(name="allowEmptyType")
    def allow_empty_type(self) -> Optional[bool]:
        return pulumi.get(self, "allow_empty_type")

    @property
    @pulumi.getter(name="allowRepeatedParameterName")
    def allow_repeated_parameter_name(self) -> Optional[bool]:
        return pulumi.get(self, "allow_repeated_parameter_name")

    @property
    @pulumi.getter(name="attackSignaturesCheck")
    def attack_signatures_check(self) -> Optional[bool]:
        return pulumi.get(self, "attack_signatures_check")

    @property
    @pulumi.getter(name="checkMaxValueLength")
    def check_max_value_length(self) -> Optional[bool]:
        return pulumi.get(self, "check_max_value_length")

    @property
    @pulumi.getter(name="checkMinValueLength")
    def check_min_value_length(self) -> Optional[bool]:
        return pulumi.get(self, "check_min_value_length")

    @property
    @pulumi.getter(name="dataType")
    def data_type(self) -> Optional[str]:
        return pulumi.get(self, "data_type")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableRegularExpression")
    def enable_regular_expression(self) -> Optional[bool]:
        return pulumi.get(self, "enable_regular_expression")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isBase64")
    def is_base64(self) -> Optional[bool]:
        return pulumi.get(self, "is_base64")

    @property
    @pulumi.getter(name="isCookie")
    def is_cookie(self) -> Optional[bool]:
        return pulumi.get(self, "is_cookie")

    @property
    @pulumi.getter(name="isHeader")
    def is_header(self) -> Optional[bool]:
        return pulumi.get(self, "is_header")

    @property
    @pulumi.getter
    def json(self) -> str:
        return pulumi.get(self, "json")

    @property
    @pulumi.getter
    def level(self) -> Optional[str]:
        return pulumi.get(self, "level")

    @property
    @pulumi.getter
    def mandatory(self) -> Optional[bool]:
        return pulumi.get(self, "mandatory")

    @property
    @pulumi.getter(name="metacharsOnParameterValueCheck")
    def metachars_on_parameter_value_check(self) -> Optional[bool]:
        return pulumi.get(self, "metachars_on_parameter_value_check")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parameterLocation")
    def parameter_location(self) -> Optional[str]:
        return pulumi.get(self, "parameter_location")

    @property
    @pulumi.getter(name="performStaging")
    def perform_staging(self) -> Optional[bool]:
        return pulumi.get(self, "perform_staging")

    @property
    @pulumi.getter(name="sensitiveParameter")
    def sensitive_parameter(self) -> Optional[bool]:
        return pulumi.get(self, "sensitive_parameter")

    @property
    @pulumi.getter(name="signatureOverridesDisables")
    def signature_overrides_disables(self) -> Optional[Sequence[int]]:
        return pulumi.get(self, "signature_overrides_disables")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def url(self) -> Optional['outputs.GetWafEntityParameterUrlResult']:
        return pulumi.get(self, "url")

    @property
    @pulumi.getter(name="valueType")
    def value_type(self) -> Optional[str]:
        return pulumi.get(self, "value_type")


class AwaitableGetWafEntityParameterResult(GetWafEntityParameterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWafEntityParameterResult(
            allow_empty_type=self.allow_empty_type,
            allow_repeated_parameter_name=self.allow_repeated_parameter_name,
            attack_signatures_check=self.attack_signatures_check,
            check_max_value_length=self.check_max_value_length,
            check_min_value_length=self.check_min_value_length,
            data_type=self.data_type,
            description=self.description,
            enable_regular_expression=self.enable_regular_expression,
            id=self.id,
            is_base64=self.is_base64,
            is_cookie=self.is_cookie,
            is_header=self.is_header,
            json=self.json,
            level=self.level,
            mandatory=self.mandatory,
            metachars_on_parameter_value_check=self.metachars_on_parameter_value_check,
            name=self.name,
            parameter_location=self.parameter_location,
            perform_staging=self.perform_staging,
            sensitive_parameter=self.sensitive_parameter,
            signature_overrides_disables=self.signature_overrides_disables,
            type=self.type,
            url=self.url,
            value_type=self.value_type)


def get_waf_entity_parameter(allow_empty_type: Optional[bool] = None,
                             allow_repeated_parameter_name: Optional[bool] = None,
                             attack_signatures_check: Optional[bool] = None,
                             check_max_value_length: Optional[bool] = None,
                             check_min_value_length: Optional[bool] = None,
                             data_type: Optional[str] = None,
                             description: Optional[str] = None,
                             enable_regular_expression: Optional[bool] = None,
                             is_base64: Optional[bool] = None,
                             is_cookie: Optional[bool] = None,
                             is_header: Optional[bool] = None,
                             json: Optional[str] = None,
                             level: Optional[str] = None,
                             mandatory: Optional[bool] = None,
                             metachars_on_parameter_value_check: Optional[bool] = None,
                             name: Optional[str] = None,
                             parameter_location: Optional[str] = None,
                             perform_staging: Optional[bool] = None,
                             sensitive_parameter: Optional[bool] = None,
                             signature_overrides_disables: Optional[Sequence[int]] = None,
                             type: Optional[str] = None,
                             url: Optional[pulumi.InputType['GetWafEntityParameterUrlArgs']] = None,
                             value_type: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWafEntityParameterResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['allowEmptyType'] = allow_empty_type
    __args__['allowRepeatedParameterName'] = allow_repeated_parameter_name
    __args__['attackSignaturesCheck'] = attack_signatures_check
    __args__['checkMaxValueLength'] = check_max_value_length
    __args__['checkMinValueLength'] = check_min_value_length
    __args__['dataType'] = data_type
    __args__['description'] = description
    __args__['enableRegularExpression'] = enable_regular_expression
    __args__['isBase64'] = is_base64
    __args__['isCookie'] = is_cookie
    __args__['isHeader'] = is_header
    __args__['json'] = json
    __args__['level'] = level
    __args__['mandatory'] = mandatory
    __args__['metacharsOnParameterValueCheck'] = metachars_on_parameter_value_check
    __args__['name'] = name
    __args__['parameterLocation'] = parameter_location
    __args__['performStaging'] = perform_staging
    __args__['sensitiveParameter'] = sensitive_parameter
    __args__['signatureOverridesDisables'] = signature_overrides_disables
    __args__['type'] = type
    __args__['url'] = url
    __args__['valueType'] = value_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getWafEntityParameter:getWafEntityParameter', __args__, opts=opts, typ=GetWafEntityParameterResult).value

    return AwaitableGetWafEntityParameterResult(
        allow_empty_type=pulumi.get(__ret__, 'allow_empty_type'),
        allow_repeated_parameter_name=pulumi.get(__ret__, 'allow_repeated_parameter_name'),
        attack_signatures_check=pulumi.get(__ret__, 'attack_signatures_check'),
        check_max_value_length=pulumi.get(__ret__, 'check_max_value_length'),
        check_min_value_length=pulumi.get(__ret__, 'check_min_value_length'),
        data_type=pulumi.get(__ret__, 'data_type'),
        description=pulumi.get(__ret__, 'description'),
        enable_regular_expression=pulumi.get(__ret__, 'enable_regular_expression'),
        id=pulumi.get(__ret__, 'id'),
        is_base64=pulumi.get(__ret__, 'is_base64'),
        is_cookie=pulumi.get(__ret__, 'is_cookie'),
        is_header=pulumi.get(__ret__, 'is_header'),
        json=pulumi.get(__ret__, 'json'),
        level=pulumi.get(__ret__, 'level'),
        mandatory=pulumi.get(__ret__, 'mandatory'),
        metachars_on_parameter_value_check=pulumi.get(__ret__, 'metachars_on_parameter_value_check'),
        name=pulumi.get(__ret__, 'name'),
        parameter_location=pulumi.get(__ret__, 'parameter_location'),
        perform_staging=pulumi.get(__ret__, 'perform_staging'),
        sensitive_parameter=pulumi.get(__ret__, 'sensitive_parameter'),
        signature_overrides_disables=pulumi.get(__ret__, 'signature_overrides_disables'),
        type=pulumi.get(__ret__, 'type'),
        url=pulumi.get(__ret__, 'url'),
        value_type=pulumi.get(__ret__, 'value_type'))


@_utilities.lift_output_func(get_waf_entity_parameter)
def get_waf_entity_parameter_output(allow_empty_type: Optional[pulumi.Input[Optional[bool]]] = None,
                                    allow_repeated_parameter_name: Optional[pulumi.Input[Optional[bool]]] = None,
                                    attack_signatures_check: Optional[pulumi.Input[Optional[bool]]] = None,
                                    check_max_value_length: Optional[pulumi.Input[Optional[bool]]] = None,
                                    check_min_value_length: Optional[pulumi.Input[Optional[bool]]] = None,
                                    data_type: Optional[pulumi.Input[Optional[str]]] = None,
                                    description: Optional[pulumi.Input[Optional[str]]] = None,
                                    enable_regular_expression: Optional[pulumi.Input[Optional[bool]]] = None,
                                    is_base64: Optional[pulumi.Input[Optional[bool]]] = None,
                                    is_cookie: Optional[pulumi.Input[Optional[bool]]] = None,
                                    is_header: Optional[pulumi.Input[Optional[bool]]] = None,
                                    json: Optional[pulumi.Input[Optional[str]]] = None,
                                    level: Optional[pulumi.Input[Optional[str]]] = None,
                                    mandatory: Optional[pulumi.Input[Optional[bool]]] = None,
                                    metachars_on_parameter_value_check: Optional[pulumi.Input[Optional[bool]]] = None,
                                    name: Optional[pulumi.Input[str]] = None,
                                    parameter_location: Optional[pulumi.Input[Optional[str]]] = None,
                                    perform_staging: Optional[pulumi.Input[Optional[bool]]] = None,
                                    sensitive_parameter: Optional[pulumi.Input[Optional[bool]]] = None,
                                    signature_overrides_disables: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                                    type: Optional[pulumi.Input[Optional[str]]] = None,
                                    url: Optional[pulumi.Input[Optional[pulumi.InputType['GetWafEntityParameterUrlArgs']]]] = None,
                                    value_type: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetWafEntityParameterResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IpsecPolicyArgs', 'IpsecPolicy']

@pulumi.input_type
class IpsecPolicyArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 auth_algorithm: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 encrypt_algorithm: Optional[pulumi.Input[str]] = None,
                 ipcomp: Optional[pulumi.Input[str]] = None,
                 kb_lifetime: Optional[pulumi.Input[int]] = None,
                 lifetime: Optional[pulumi.Input[int]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 perfect_forward_secrecy: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 tunnel_local_address: Optional[pulumi.Input[str]] = None,
                 tunnel_remote_address: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a IpsecPolicy resource.
        :param pulumi.Input[str] name: Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        :param pulumi.Input[str] auth_algorithm: Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
               aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        :param pulumi.Input[str] description: Description of the IPSec policy.
        :param pulumi.Input[str] encrypt_algorithm: Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
               aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        :param pulumi.Input[str] ipcomp: Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        :param pulumi.Input[int] kb_lifetime: Specifies the length of time before the IKE security association expires, in kilobytes.
        :param pulumi.Input[int] lifetime: Specifies the length of time before the IKE security association expires, in minutes.
        :param pulumi.Input[str] mode: Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        :param pulumi.Input[str] perfect_forward_secrecy: Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
               modp4096, modp6144, modp8192`
        :param pulumi.Input[str] protocol: Specifies the IPsec protocol. Valid choices are: `ah, esp`
        :param pulumi.Input[str] tunnel_local_address: Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        :param pulumi.Input[str] tunnel_remote_address: Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        pulumi.set(__self__, "name", name)
        if auth_algorithm is not None:
            pulumi.set(__self__, "auth_algorithm", auth_algorithm)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if encrypt_algorithm is not None:
            pulumi.set(__self__, "encrypt_algorithm", encrypt_algorithm)
        if ipcomp is not None:
            pulumi.set(__self__, "ipcomp", ipcomp)
        if kb_lifetime is not None:
            pulumi.set(__self__, "kb_lifetime", kb_lifetime)
        if lifetime is not None:
            pulumi.set(__self__, "lifetime", lifetime)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if perfect_forward_secrecy is not None:
            pulumi.set(__self__, "perfect_forward_secrecy", perfect_forward_secrecy)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if tunnel_local_address is not None:
            pulumi.set(__self__, "tunnel_local_address", tunnel_local_address)
        if tunnel_remote_address is not None:
            pulumi.set(__self__, "tunnel_remote_address", tunnel_remote_address)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="authAlgorithm")
    def auth_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
        aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        """
        return pulumi.get(self, "auth_algorithm")

    @auth_algorithm.setter
    def auth_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_algorithm", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the IPSec policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="encryptAlgorithm")
    def encrypt_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
        aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        """
        return pulumi.get(self, "encrypt_algorithm")

    @encrypt_algorithm.setter
    def encrypt_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypt_algorithm", value)

    @property
    @pulumi.getter
    def ipcomp(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        """
        return pulumi.get(self, "ipcomp")

    @ipcomp.setter
    def ipcomp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipcomp", value)

    @property
    @pulumi.getter(name="kbLifetime")
    def kb_lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the length of time before the IKE security association expires, in kilobytes.
        """
        return pulumi.get(self, "kb_lifetime")

    @kb_lifetime.setter
    def kb_lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "kb_lifetime", value)

    @property
    @pulumi.getter
    def lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the length of time before the IKE security association expires, in minutes.
        """
        return pulumi.get(self, "lifetime")

    @lifetime.setter
    def lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lifetime", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter(name="perfectForwardSecrecy")
    def perfect_forward_secrecy(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
        modp4096, modp6144, modp8192`
        """
        return pulumi.get(self, "perfect_forward_secrecy")

    @perfect_forward_secrecy.setter
    def perfect_forward_secrecy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "perfect_forward_secrecy", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IPsec protocol. Valid choices are: `ah, esp`
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="tunnelLocalAddress")
    def tunnel_local_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_local_address")

    @tunnel_local_address.setter
    def tunnel_local_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tunnel_local_address", value)

    @property
    @pulumi.getter(name="tunnelRemoteAddress")
    def tunnel_remote_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_remote_address")

    @tunnel_remote_address.setter
    def tunnel_remote_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tunnel_remote_address", value)


@pulumi.input_type
class _IpsecPolicyState:
    def __init__(__self__, *,
                 auth_algorithm: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 encrypt_algorithm: Optional[pulumi.Input[str]] = None,
                 ipcomp: Optional[pulumi.Input[str]] = None,
                 kb_lifetime: Optional[pulumi.Input[int]] = None,
                 lifetime: Optional[pulumi.Input[int]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 perfect_forward_secrecy: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 tunnel_local_address: Optional[pulumi.Input[str]] = None,
                 tunnel_remote_address: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IpsecPolicy resources.
        :param pulumi.Input[str] auth_algorithm: Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
               aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        :param pulumi.Input[str] description: Description of the IPSec policy.
        :param pulumi.Input[str] encrypt_algorithm: Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
               aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        :param pulumi.Input[str] ipcomp: Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        :param pulumi.Input[int] kb_lifetime: Specifies the length of time before the IKE security association expires, in kilobytes.
        :param pulumi.Input[int] lifetime: Specifies the length of time before the IKE security association expires, in minutes.
        :param pulumi.Input[str] mode: Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        :param pulumi.Input[str] name: Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        :param pulumi.Input[str] perfect_forward_secrecy: Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
               modp4096, modp6144, modp8192`
        :param pulumi.Input[str] protocol: Specifies the IPsec protocol. Valid choices are: `ah, esp`
        :param pulumi.Input[str] tunnel_local_address: Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        :param pulumi.Input[str] tunnel_remote_address: Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        if auth_algorithm is not None:
            pulumi.set(__self__, "auth_algorithm", auth_algorithm)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if encrypt_algorithm is not None:
            pulumi.set(__self__, "encrypt_algorithm", encrypt_algorithm)
        if ipcomp is not None:
            pulumi.set(__self__, "ipcomp", ipcomp)
        if kb_lifetime is not None:
            pulumi.set(__self__, "kb_lifetime", kb_lifetime)
        if lifetime is not None:
            pulumi.set(__self__, "lifetime", lifetime)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if perfect_forward_secrecy is not None:
            pulumi.set(__self__, "perfect_forward_secrecy", perfect_forward_secrecy)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if tunnel_local_address is not None:
            pulumi.set(__self__, "tunnel_local_address", tunnel_local_address)
        if tunnel_remote_address is not None:
            pulumi.set(__self__, "tunnel_remote_address", tunnel_remote_address)

    @property
    @pulumi.getter(name="authAlgorithm")
    def auth_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
        aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        """
        return pulumi.get(self, "auth_algorithm")

    @auth_algorithm.setter
    def auth_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_algorithm", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the IPSec policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="encryptAlgorithm")
    def encrypt_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
        aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        """
        return pulumi.get(self, "encrypt_algorithm")

    @encrypt_algorithm.setter
    def encrypt_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypt_algorithm", value)

    @property
    @pulumi.getter
    def ipcomp(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        """
        return pulumi.get(self, "ipcomp")

    @ipcomp.setter
    def ipcomp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipcomp", value)

    @property
    @pulumi.getter(name="kbLifetime")
    def kb_lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the length of time before the IKE security association expires, in kilobytes.
        """
        return pulumi.get(self, "kb_lifetime")

    @kb_lifetime.setter
    def kb_lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "kb_lifetime", value)

    @property
    @pulumi.getter
    def lifetime(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the length of time before the IKE security association expires, in minutes.
        """
        return pulumi.get(self, "lifetime")

    @lifetime.setter
    def lifetime(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lifetime", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="perfectForwardSecrecy")
    def perfect_forward_secrecy(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
        modp4096, modp6144, modp8192`
        """
        return pulumi.get(self, "perfect_forward_secrecy")

    @perfect_forward_secrecy.setter
    def perfect_forward_secrecy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "perfect_forward_secrecy", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IPsec protocol. Valid choices are: `ah, esp`
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="tunnelLocalAddress")
    def tunnel_local_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_local_address")

    @tunnel_local_address.setter
    def tunnel_local_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tunnel_local_address", value)

    @property
    @pulumi.getter(name="tunnelRemoteAddress")
    def tunnel_remote_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_remote_address")

    @tunnel_remote_address.setter
    def tunnel_remote_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tunnel_remote_address", value)


class IpsecPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_algorithm: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 encrypt_algorithm: Optional[pulumi.Input[str]] = None,
                 ipcomp: Optional[pulumi.Input[str]] = None,
                 kb_lifetime: Optional[pulumi.Input[int]] = None,
                 lifetime: Optional[pulumi.Input[int]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 perfect_forward_secrecy: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 tunnel_local_address: Optional[pulumi.Input[str]] = None,
                 tunnel_remote_address: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `IpsecPolicy` Manage IPSec policies on a BIG-IP

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/test-policy)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_policy = f5bigip.IpsecPolicy("test-policy",
            auth_algorithm="sha1",
            description="created by terraform provider",
            encrypt_algorithm="3des",
            ipcomp="deflate",
            lifetime=3,
            mode="tunnel",
            name="/Common/test-policy",
            protocol="esp",
            tunnel_local_address="192.168.1.1",
            tunnel_remote_address="10.10.1.1")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_algorithm: Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
               aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        :param pulumi.Input[str] description: Description of the IPSec policy.
        :param pulumi.Input[str] encrypt_algorithm: Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
               aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        :param pulumi.Input[str] ipcomp: Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        :param pulumi.Input[int] kb_lifetime: Specifies the length of time before the IKE security association expires, in kilobytes.
        :param pulumi.Input[int] lifetime: Specifies the length of time before the IKE security association expires, in minutes.
        :param pulumi.Input[str] mode: Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        :param pulumi.Input[str] name: Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        :param pulumi.Input[str] perfect_forward_secrecy: Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
               modp4096, modp6144, modp8192`
        :param pulumi.Input[str] protocol: Specifies the IPsec protocol. Valid choices are: `ah, esp`
        :param pulumi.Input[str] tunnel_local_address: Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        :param pulumi.Input[str] tunnel_remote_address: Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpsecPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `IpsecPolicy` Manage IPSec policies on a BIG-IP

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/test-policy)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_policy = f5bigip.IpsecPolicy("test-policy",
            auth_algorithm="sha1",
            description="created by terraform provider",
            encrypt_algorithm="3des",
            ipcomp="deflate",
            lifetime=3,
            mode="tunnel",
            name="/Common/test-policy",
            protocol="esp",
            tunnel_local_address="192.168.1.1",
            tunnel_remote_address="10.10.1.1")
        ```

        :param str resource_name: The name of the resource.
        :param IpsecPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpsecPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_algorithm: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 encrypt_algorithm: Optional[pulumi.Input[str]] = None,
                 ipcomp: Optional[pulumi.Input[str]] = None,
                 kb_lifetime: Optional[pulumi.Input[int]] = None,
                 lifetime: Optional[pulumi.Input[int]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 perfect_forward_secrecy: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 tunnel_local_address: Optional[pulumi.Input[str]] = None,
                 tunnel_remote_address: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpsecPolicyArgs.__new__(IpsecPolicyArgs)

            __props__.__dict__["auth_algorithm"] = auth_algorithm
            __props__.__dict__["description"] = description
            __props__.__dict__["encrypt_algorithm"] = encrypt_algorithm
            __props__.__dict__["ipcomp"] = ipcomp
            __props__.__dict__["kb_lifetime"] = kb_lifetime
            __props__.__dict__["lifetime"] = lifetime
            __props__.__dict__["mode"] = mode
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["perfect_forward_secrecy"] = perfect_forward_secrecy
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["tunnel_local_address"] = tunnel_local_address
            __props__.__dict__["tunnel_remote_address"] = tunnel_remote_address
        super(IpsecPolicy, __self__).__init__(
            'f5bigip:index/ipsecPolicy:IpsecPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_algorithm: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            encrypt_algorithm: Optional[pulumi.Input[str]] = None,
            ipcomp: Optional[pulumi.Input[str]] = None,
            kb_lifetime: Optional[pulumi.Input[int]] = None,
            lifetime: Optional[pulumi.Input[int]] = None,
            mode: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            perfect_forward_secrecy: Optional[pulumi.Input[str]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            tunnel_local_address: Optional[pulumi.Input[str]] = None,
            tunnel_remote_address: Optional[pulumi.Input[str]] = None) -> 'IpsecPolicy':
        """
        Get an existing IpsecPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_algorithm: Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
               aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        :param pulumi.Input[str] description: Description of the IPSec policy.
        :param pulumi.Input[str] encrypt_algorithm: Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
               aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        :param pulumi.Input[str] ipcomp: Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        :param pulumi.Input[int] kb_lifetime: Specifies the length of time before the IKE security association expires, in kilobytes.
        :param pulumi.Input[int] lifetime: Specifies the length of time before the IKE security association expires, in minutes.
        :param pulumi.Input[str] mode: Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        :param pulumi.Input[str] name: Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        :param pulumi.Input[str] perfect_forward_secrecy: Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
               modp4096, modp6144, modp8192`
        :param pulumi.Input[str] protocol: Specifies the IPsec protocol. Valid choices are: `ah, esp`
        :param pulumi.Input[str] tunnel_local_address: Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        :param pulumi.Input[str] tunnel_remote_address: Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpsecPolicyState.__new__(_IpsecPolicyState)

        __props__.__dict__["auth_algorithm"] = auth_algorithm
        __props__.__dict__["description"] = description
        __props__.__dict__["encrypt_algorithm"] = encrypt_algorithm
        __props__.__dict__["ipcomp"] = ipcomp
        __props__.__dict__["kb_lifetime"] = kb_lifetime
        __props__.__dict__["lifetime"] = lifetime
        __props__.__dict__["mode"] = mode
        __props__.__dict__["name"] = name
        __props__.__dict__["perfect_forward_secrecy"] = perfect_forward_secrecy
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["tunnel_local_address"] = tunnel_local_address
        __props__.__dict__["tunnel_remote_address"] = tunnel_remote_address
        return IpsecPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authAlgorithm")
    def auth_algorithm(self) -> pulumi.Output[str]:
        """
        Specifies the algorithm to use for IKE authentication. Valid choices are: `sha1, sha256, sha384, sha512, aes-gcm128,
        aes-gcm192, aes-gcm256, aes-gmac128, aes-gmac192, aes-gmac256`
        """
        return pulumi.get(self, "auth_algorithm")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the IPSec policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="encryptAlgorithm")
    def encrypt_algorithm(self) -> pulumi.Output[str]:
        """
        Specifies the algorithm to use for IKE encryption. Valid choices are: `null, 3des, aes128, aes192, aes256, aes-gmac256,
        aes-gmac192, aes-gmac128, aes-gcm256, aes-gcm192, aes-gcm256, aes-gcm128`
        """
        return pulumi.get(self, "encrypt_algorithm")

    @property
    @pulumi.getter
    def ipcomp(self) -> pulumi.Output[str]:
        """
        Specifies whether to use IPComp encapsulation. Valid choices are: `none", null", deflate`
        """
        return pulumi.get(self, "ipcomp")

    @property
    @pulumi.getter(name="kbLifetime")
    def kb_lifetime(self) -> pulumi.Output[int]:
        """
        Specifies the length of time before the IKE security association expires, in kilobytes.
        """
        return pulumi.get(self, "kb_lifetime")

    @property
    @pulumi.getter
    def lifetime(self) -> pulumi.Output[int]:
        """
        Specifies the length of time before the IKE security association expires, in minutes.
        """
        return pulumi.get(self, "lifetime")

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Output[str]:
        """
        Specifies the processing mode. Valid choices are: `transport, interface, isession, tunnel`
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the IPSec policy,it should be "full path".The full path is the combination of the partition + name of the IPSec policy.(For example `/Common/test-policy`)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="perfectForwardSecrecy")
    def perfect_forward_secrecy(self) -> pulumi.Output[str]:
        """
        Specifies the Diffie-Hellman group to use for IKE Phase 2 negotiation. Valid choices are: `none, modp768, modp1024, modp1536, modp2048, modp3072,
        modp4096, modp6144, modp8192`
        """
        return pulumi.get(self, "perfect_forward_secrecy")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[str]:
        """
        Specifies the IPsec protocol. Valid choices are: `ah, esp`
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="tunnelLocalAddress")
    def tunnel_local_address(self) -> pulumi.Output[str]:
        """
        Specifies the local endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_local_address")

    @property
    @pulumi.getter(name="tunnelRemoteAddress")
    def tunnel_remote_address(self) -> pulumi.Output[str]:
        """
        Specifies the remote endpoint IP address of the IPsec tunnel. This parameter is only valid when mode is tunnel.
        """
        return pulumi.get(self, "tunnel_remote_address")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['FastApplicationArgs', 'FastApplication']

@pulumi.input_type
class FastApplicationArgs:
    def __init__(__self__, *,
                 fast_json: pulumi.Input[str],
                 template: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FastApplication resource.
        :param pulumi.Input[str] fast_json: Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[str] template: Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        """
        pulumi.set(__self__, "fast_json", fast_json)
        if template is not None:
            pulumi.set(__self__, "template", template)

    @property
    @pulumi.getter(name="fastJson")
    def fast_json(self) -> pulumi.Input[str]:
        """
        Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "fast_json")

    @fast_json.setter
    def fast_json(self, value: pulumi.Input[str]):
        pulumi.set(self, "fast_json", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[str]]:
        """
        Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template", value)


@pulumi.input_type
class _FastApplicationState:
    def __init__(__self__, *,
                 application: Optional[pulumi.Input[str]] = None,
                 fast_json: Optional[pulumi.Input[str]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 tenant: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FastApplication resources.
        :param pulumi.Input[str] application: A FAST application name.
               
               
               
               * `FAST documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-templates/latest/
        :param pulumi.Input[str] fast_json: Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[str] template: Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        :param pulumi.Input[str] tenant: A FAST tenant name on which you want to manage application.
        """
        if application is not None:
            pulumi.set(__self__, "application", application)
        if fast_json is not None:
            pulumi.set(__self__, "fast_json", fast_json)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if tenant is not None:
            pulumi.set(__self__, "tenant", tenant)

    @property
    @pulumi.getter
    def application(self) -> Optional[pulumi.Input[str]]:
        """
        A FAST application name.



        * `FAST documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-templates/latest/
        """
        return pulumi.get(self, "application")

    @application.setter
    def application(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application", value)

    @property
    @pulumi.getter(name="fastJson")
    def fast_json(self) -> Optional[pulumi.Input[str]]:
        """
        Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "fast_json")

    @fast_json.setter
    def fast_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fast_json", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[str]]:
        """
        Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter
    def tenant(self) -> Optional[pulumi.Input[str]]:
        """
        A FAST tenant name on which you want to manage application.
        """
        return pulumi.get(self, "tenant")

    @tenant.setter
    def tenant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant", value)


class FastApplication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 fast_json: Optional[pulumi.Input[str]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `FastApplication` This resource will create and manage FAST applications on BIG-IP from provided JSON declaration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        foo_app = f5bigip.FastApplication("foo-app",
            fast_json=(lambda path: open(path).read())("new_fast_app.json"),
            template="examples/simple_http")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] fast_json: Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[str] template: Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FastApplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `FastApplication` This resource will create and manage FAST applications on BIG-IP from provided JSON declaration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        foo_app = f5bigip.FastApplication("foo-app",
            fast_json=(lambda path: open(path).read())("new_fast_app.json"),
            template="examples/simple_http")
        ```

        :param str resource_name: The name of the resource.
        :param FastApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FastApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 fast_json: Optional[pulumi.Input[str]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FastApplicationArgs.__new__(FastApplicationArgs)

            if fast_json is None and not opts.urn:
                raise TypeError("Missing required property 'fast_json'")
            __props__.__dict__["fast_json"] = fast_json
            __props__.__dict__["template"] = template
            __props__.__dict__["application"] = None
            __props__.__dict__["tenant"] = None
        super(FastApplication, __self__).__init__(
            'f5bigip:index/fastApplication:FastApplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application: Optional[pulumi.Input[str]] = None,
            fast_json: Optional[pulumi.Input[str]] = None,
            template: Optional[pulumi.Input[str]] = None,
            tenant: Optional[pulumi.Input[str]] = None) -> 'FastApplication':
        """
        Get an existing FastApplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application: A FAST application name.
               
               
               
               * `FAST documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-templates/latest/
        :param pulumi.Input[str] fast_json: Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[str] template: Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        :param pulumi.Input[str] tenant: A FAST tenant name on which you want to manage application.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FastApplicationState.__new__(_FastApplicationState)

        __props__.__dict__["application"] = application
        __props__.__dict__["fast_json"] = fast_json
        __props__.__dict__["template"] = template
        __props__.__dict__["tenant"] = tenant
        return FastApplication(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def application(self) -> pulumi.Output[str]:
        """
        A FAST application name.



        * `FAST documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-templates/latest/
        """
        return pulumi.get(self, "application")

    @property
    @pulumi.getter(name="fastJson")
    def fast_json(self) -> pulumi.Output[str]:
        """
        Path/Filename of Declarative FAST JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "fast_json")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[Optional[str]]:
        """
        Name of installed FAST template used to create FAST application. This parameter is required when creating new resource.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter
    def tenant(self) -> pulumi.Output[str]:
        """
        A FAST tenant name on which you want to manage application.
        """
        return pulumi.get(self, "tenant")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .big_ip_license import *
from .dns import *
from .i_app import *
from .ntp import *
from .provision import *
from .snmp import *
from .snmp_traps import *
from ._inputs import *
from . import outputs
